#include "Money.h"
#include "Reader.h"
#include "Writer.h"



void Money::acceptReader(Reader* reader)
{
	amount = (Amount&)(reader->readValue());
	currency = (Currency&)(reader->readValue());
}

void Money::acceptWriter(Writer* writer) const
{
	writer->writeValue(amount);
	writer->writeValue(currency);
}

const char* Money::typeName() const
{
	return "Money";
}

const String Money::asString() const
{
	return currency.asString() + amount.asString();
}

bool Money::isValid() const
{
	return true;
}

bool Money::operator==(const Money& m)
{
	return ( amount == m.amount ) && ( currency == m.currency );
}

Money& Money::operator=(const Money& m)
{
	amount = m.amount;
	currency = m.currency;
	return *this;
}

Money& Money::operator+=(const Money& m)
{
	if (currency == m.currency)
		amount += m.amount;
	return *this;
}

Money& Money::operator+=(const Amount& a)
{
	amount += a;
	return *this;
}

Money& Money::operator-=(const Money& m)
{
	if (currency == m.currency)
		amount -= m.amount;
	return *this;
}

Money& Money::operator-=(const Amount& a)
{
	amount -= a;
	return *this;
}

Money::Money() : amount(0.0), currency("CHF")
{
}

Money::Money(Money& Money) : amount(0.0), currency("CHF")
{
	amount = 0.0;
	currency = "CHF";
}

Money::Money(Amount& a, Currency& c) : amount(a), currency(c)
{
}

